@@ -2,7 +2,7 @@
 from __future__ import generators
 
 # These region estimators must stay - despite not appearing to be used!!
-from region_estimators.diffusion_estimator import DiffusionEstimator
+from region_estimators.concentric_regions_estimator import ConcentricRegionsEstimator
 from region_estimators.distance_simple_estimator import DistanceSimpleEstimator
 
 
@@ -11,7 +11,7 @@ class RegionEstimatorFactory:
 
     # A Template Method:
     @staticmethod
-    def create(method_name, sites, regions, actuals, verbose=DiffusionEstimator.VERBOSE_DEFAULT):
+    def create(method_name, sites, regions, actuals, verbose=ConcentricRegionsEstimator.VERBOSE_DEFAULT):
         class_name = RegionEstimatorFactory.get_classname(method_name)
         if class_name not in RegionEstimatorFactory.factories:
             RegionEstimatorFactory.factories[class_name] = eval(class_name + '.Factory()')
@@ -21,8 +21,8 @@ class RegionEstimatorFactory:
 
     @staticmethod
     def get_classname(method_name):
-        if method_name == 'diffusion':
-            return 'DiffusionEstimator'
+        if method_name == 'concentric-regions':
+            return 'ConcentricRegionsEstimator'
         elif method_name == 'distance-simple':
             return 'DistanceSimpleEstimator'
         else:
